/**
 * A scratch card custom element made with Lit.
 * Inspired from this CodePen made by Totati: https://codepen.io/Totati/pen/pPXrJV
 *
 * @author Matteo De Nardis <matteodn96@gmail.com>
 */
import { LitElement, PropertyValues } from "lit";
export declare class ScratchCard extends LitElement {
    #private;
    static styles: import("lit").CSSResult;
    /**
     * Scales up (> 1) or down (< 1) the size of the uncovered area with a single scratch.
     * @defaultValue `1`
     */
    brushScale: number;
    /**
     * If true, the cover image is centered in the scratching area.
     * @defaultValue `false`
     */
    centerCover: boolean;
    /**
     * URL path (relative or absolute) of the image to be used as cover to scratch.
     * If undefined, then the scratch area will be filled with a rectangle with style specified by the `fillColor` property.
     * @defaultValue `undefined`
     */
    coverSrc?: string;
    /**
     * Specifies the color to use to fill the scratch area if a `coverSrc` is not provided.
     * If this is an invalid value while the `coverSrc` is missing, the scratch card will show as already scratched.
     * @defaultValue `white`
     */
    fillColor: string;
    /**
     * Whether to scale or not the cover to avoid leaving empty spaces in the scratch area.
     * This can happen when the scratch area and the cover image have not the same aspect ratio.
     * To set as true, just add the attribute; for example, both `preserveAspectRatio` and `preserveAspectRatio="false"` evaluate to `true`
     * (the behaviour is the same to the standard `disabled` attribute).
     * @defaultValue `false`
     */
    preserveAspectRatio: boolean;
    /**
     * Percentage threshold to consider the card as fully scratched.
     * For instance, if `showAllAt="80"` the content will be entirely revealed when the 80% of the card's surface is scratched.
     * @defaultValue `100`
     */
    showAllAt: number;
    /**
     * Whether to stop emitting or not warnings to the browser console, such as `"The image is being scaled up"`.
     * @defaultValue `false`
     */
    silenceWarnings: boolean;
    constructor();
    render(): import("lit").TemplateResult<1>;
    updated(_changedProperties: PropertyValues): void;
    disconnectedCallback(): void;
    /**
     * Method to manually clear the card, revealing immediately the underlying content.
     */
    clearCard(): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "scratch-card": ScratchCard;
    }
}
//# sourceMappingURL=scratch-card.d.ts.map